#!/bin/bash

warn=0

HELAC=`pwd`/

if [ $# -eq 0 ]
then
	echo Usage:
	echo run.sh "<user_input_file> <environmental_variables_file>"
	echo "if <myenv file> is omitted, myenv will be used"
	exit
fi

if [ $# -eq 1 ]
then
	echo "Second argument omitted"
	echo "Using myenv as environment file"
	envfile="myenv"
else
	envfile=$2
fi

PATH=.:$PATH

source $envfile
echo "FC=" $FC
echo "LD_LIBRARY_PATH=" $LD_LIBRARY_PATH
echo "LHAPDFLIB=" $LHAPDFLIB

if [ "$FC" = "" ]
then
	echo "***************************************************"
	echo "********please define FC *******"
	echo "********PLEASE EDIT the file" $envfile "*****************"
	echo "********or use one of the other myenv's files *****"
	echo "***************************************************"
	exit
fi

x=`which $FC`
if [ -z $x ]
then
	echo "$FC is not a valid fortran compiler"
	echo "Please edit $envfile file"
	exit
fi

if [ ! -z $FORTRAN_LIBRARIES ]
then
	if [ ! -d $FORTRAN_LIBRARIES ]
	then
		echo "***************************************************"
		echo "$FORTRAN_LIBRARIES is not a valid path for fortran libraries"
		echo "Please edit $envfile file"
		echo "***************************************************"
		exit
	fi
fi

x=0
if [ ! -z $LHAPDFLIB ]
then
	x=1
else
	if [ ! -z $LHAPDFSETS ]
	then
		x=1
	fi
fi

if [ $x -eq 1 ]
then
	if [ ! -d $LHAPDFLIB ]
	then
		echo "***************************************************"
		echo "$LHAPDFLIB is not a valid path for LHAPDF libraries"
		echo "Please edit $envfile file"
		echo "***************************************************"
		exit
	fi

	if [ ! -d $LHAPDFSETS ]
	then
		echo "***************************************************"
		echo "$LHAPDFSETS is not a valid path for LHAPDF sets"
		echo "Please edit $envfile file"
		echo "***************************************************"
		exit
	fi
fi

uif=$1


compute()
{
	echo $@ | bc -l
}

lookfor()
{
	n=`grep -c "^$@ " $uif`
	if [ $n -eq 0 ]
	then
		rf=default.inp
	else
		rf=$uif

		if [ $n -gt 1 ]
		then
			echo "Warning: multiple definition of keyword $@, using the first occurence"
			warn=1
		fi
	fi
}


#Looking for wrong keywords

nkw=`wc -w keywords.list | awk '{print $1}'`

for i in `seq 1 "$nkw"`
do
	k[$i]=`sed -n "$i"p keywords.list`
done

len=`wc -l "$uif" | awk '{print $1}'`

for ((i=14;i<="$len";i++))
do
	x=`sed -n "$i"p "$uif" | awk '{print $1}'`

	if [ `echo $x | wc -w` -eq 1 ]
	then
		if [ `echo $x | awk '{print substr($1,1,1)}'` != "#" ]
		then
			wrong=1
			for j in `seq 1 "$nkw"`
			do
				if [ $x = ${k[$j]} ]
				then
					wrong=0
				fi
			done
		
			if [ $wrong -eq 1 ]
			then
				echo "Warning: $x in line $i of $uif is not a valid keyword" 
				warn=1
			fi
		fi
	fi

done

#Compilation phase

n=`grep -c "^${k[1]} " $uif`
if [ $n -eq 0 ]
then
	echo "Error in $uif: ${k[1]} keyword missing"
	exit
else
	if [ $n -gt 1 ]
	then
		echo "Warning: multiple definition of keyword ${k[1]}, using the first occurence"
		warn=1
	fi

	v[1]=`grep -m1 -e "^${k[1]} " $uif | awk '{print $2}'`
	case ${v[1]} in
		1) pyt="2212 2212"
		   bash parameter_pp.sh;;
		2) pyt="2212 -2212"
		   bash parameter_ppbar.sh;;
		3) pyt="-11 11";;
		*) echo "Error in $uif: wrong argument for ${k[1]}"
			exit;;
	esac
fi

#Options not given to the user
if [ ${v[1]} -ne 3 ]
then
	bash adapt_no.sh
else
	bash adapt_ee.sh
fi
bash removeZW_no.sh
bash removeW_no.sh
bash removeZ_no.sh
bash removeA_no.sh
bash specialinstvff_no.sh
bash tohisto_no.sh

v[7]=ktreweight
v[8]=largeNclimit

for i in `seq 7 8`
do
	lookfor ${k[$i]}

	x=`grep -m1 -e "^${k[$i]} " $rf | awk '{print $2}'`
	case $x in
		1|t|T) bash ${v[$i]}_yes.sh;;
		0|f|F) bash ${v[$i]}_no.sh;;
		*) echo "Error in $rf: wrong argument for ${k[$i]}"
			exit;;
	esac
done

for i in 74 84
do
	lookfor ${k[$i]}

	x=`grep -m1 -e "^${k[$i]} " $rf | awk '{print $2}'`
	case $x in
		1|t|T) v[$i]=1;;
		0|f|F) v[$i]=0;;
		*) echo "Error in $rf: wrong argument for ${k[$i]}"
		   exit;;
	esac
done

if [ \( -z "$LHAPDFLIB" \) -a \( ${v[74]} -eq 1 \) ]
then
	echo "***********************************************"
	echo "Please either define correctly LHAPDF's or "
	echo "run in standalone mode "
	echo "***********************************************"
	exit
fi

#PDF

strfun=0

if [ ${v[1]} -ne 3 ]
then
	lookfor ${k[26]}
	v[26]=`grep -m1 -e "^${k[26]} " $rf | awk '{print $2}'`
else
	v[26]=0
fi

if [ ${v[26]} -ne 0 ]
then
	strfun=1

	if [ ${v[74]} -eq 1 ]
	then

		cat > phegasstrf_lha.h <<- EOF
		        parm(1)='DEFAULT'
		        parm(20)='./linkPDFsets'
		        val(1)=${v[26]}
		        call pdfset(parm,val)
		        iPDFGUP1=0
		        iPDFGUP2=0
		        iPDFSUP1=val(1)
		        iPDFSUP2=val(1)
		EOF
	fi
fi

#CUTS
if [ ${v[1]} -ne 3 ]
then
	#pp(bar) case

	for i in `seq 28 39 ; seq 76 83` 92
	do
		lookfor ${k[$i]}

		v[$i]=`grep -m1 -e "^${k[$i]} " $rf | awk '{print $2}'`
	done

	#Writing cuts_auto_pp.f
	cat > cuts_auto_pp.f <<- EOF
	       subroutine readcuts
	       include 'declare.h'
	       include 'common_masses.h'
	       include 'common_int.h'
	       include 'common_cuts.h'
	       character*24 file
	     
	       cutoff=${v[28]}
	       print*,'WARNING CUTOFF SET:',cutoff
	       ptc(3:20)=cutoff
	       drc(3:20,3:20)=0
	       etac(3:20)=20
	       ec(3:20)=cutoff
	       c1(3:20)=1
	       c2(3:20)=1
	       cc(3:20,3:20)=1
	       gmas(3:20,3:20)=cutoff
	       pi=dacos(-dnou(1))
	       
	c -- PP cuts
	c minimum lepton pt
	       ptl=${v[29]}
	c minimum quark pt
	       ptq=${v[30]}
	c minimum bottom pt
	       ptbottom=${v[76]}
	c minimum top pt
	       pttop=${v[77]}
	c minimum photon pt
	       ptg=${v[31]}
	c maximum rapidity lepton
	       etal=${v[32]}
	c maximum rapidity quark 
	       etaq=${v[33]}
	c maximum rapidity bottom 
	       etabottom=${v[78]}
	c maximum rapidity top 
	       etatop=${v[79]}
	c maximum rapidity photon
	       etag=${v[34]}
	c minimum DR lepton with lepton
	       drll=${v[35]}
	c minimum DR lepton with quark
	       drlq=${v[36]}
	c minimum DR quark with quark
	       drqq=${v[37]}
	c minimum DR photon with fermion
	       drgx=${v[38]}
	c minimum mass quark with quark
	       gqq=${v[39]}
	c minimum DR quark with b-quark
	       drqb=${v[80]}
	c minimum mass quark with b-quark
	       gqb=${v[82]}
	c minimum DR b-quark with b-quark
	       drbb=${v[81]}
	c minimum mass b-quark with b-quark
	       gbb=${v[83]}
	c minimum missing transverse momentum
	       ptmiss=${v[92]}
	EOF

	cat 2.cuts_auto_pp.f >> cuts_auto_pp.f
else
	#e+e- case

	for i in `seq 40 51` 92
	do
		lookfor ${k[$i]}

		v[$i]=`grep -m1 -e "^${k[$i]} " $rf | awk '{print $2}'`
	done

	#Writing cuts_auto_ee.f
	cat > cuts_auto_ee.f <<- EOF
	       subroutine readcuts
	       include 'declare.h'
	       include 'common_masses.h'
	       include 'common_int.h'
	       include 'common_cuts.h'
	     
	       cutoff=${v[40]}
	       print*,'WARNING: CUTOFF SET AT',cutoff
	       ec(3:20)=0
	       c1(3:20)=1
	       c2(3:20)=1
	       cc(3:20,3:20)=1
	       gmas(3:20,3:20)=cutoff
	       pi=dacos(-1.d0)

	c -- 6f cuts
	c minimum lepton energy
	       el=${v[41]}
	c minimum quark  energy
	       eq=${v[42]}
	c minimum photon energy
	       eg=${v[43]}
	c maximum cos lepton with beam
	       cl=cos(${v[44]}/180.d0*pi)
	c maximum cos quark with beam
	       cq=cos(${v[45]}/180.d0*pi)
	c maximum cos photon with beam
	       cg=cos(${v[46]}/180.d0*pi)
	c maximum cos lepton with lepton
	       cll=cos(${v[47]}/180.d0*pi)
	c maximum cos lepton with quark
	       clq=cos(${v[48]}/180.d0*pi)
	c maximum cos quark with quark
	       cqq=cos(${v[49]}/180.d0*pi)
	c maximum cos photon with fermions
	       cgx=cos(${v[50]}/180.d0*pi)
	c minimum mass quark with quark
	       gqq=${v[51]}
	c minimum missing transverse momentum
	       ptmiss=${v[92]}
	EOF

	cat 2.cuts_auto_ee.f >> cuts_auto_ee.f
fi

#CONSTANTS
for i in `seq 52 72` 87 88 89
do
	lookfor ${k[$i]}

	v[$i]=`grep -m1 -e "^${k[$i]} " $rf | awk '{print $2}'`
done

if [ ${v[87]} = "-1" ]
then
	v[87]="dnou(1)-rwm**2/rzm**2"
fi

if [ ${v[88]} = "-1" ]
then
	v[88]="dsqrt(dnou(2))*gfermi*rwm*rwm*rsw2/pi"
fi

#Writing constants.h
if [ ${v[89]} -eq  0 ]
then
cat > constants.h <<- EOF
       gfermi=${v[52]}
       rzm=${v[54]}
       rwm=${v[56]}
       rzw=${v[55]}
       rww=${v[57]}
       rsw2=${v[87]}
       alpha=${v[88]}
       gqcd=0
       alphaQCD2=${v[53]}
       if(withqcd)gqcd=dsqrt(alphaQCD2*4*pi)
       if(onlyqcd)gqcd=dsqrt(alphaQCD2*4*pi)
       parmas(32)=rzm
       parwid(32)=rzw
       parmas(33)=rwm
       parwid(33)=rww
       parmas(34)=rwm
       parwid(34)=rww
       parmas(41)=${v[58]}
       parwid(41)=${v[59]}
       parmas(1)=${v[63]}
       parmas(2)=${v[60]}
       parmas(3)=${v[66]}
       parmas(4)=${v[67]}
       parmas(5)=${v[64]}
       parmas(6)=${v[61]}
       parmas(7)=${v[69]}
       parmas(8)=${v[68]}
       parmas(9)=${v[65]}
       parmas(10)=${v[62]}
       parmas(11)=${v[71]}
       parwid(11)=${v[72]}
       parmas(12)=${v[70]}
EOF
fi

if [ $warn -eq 1 ]
then
	echo -n "Press ENTER to ignore the warning messages and continue"
	read dummy
	warn=0
fi

#Compiling

rm -f main_mc_dp.exe

touch *.f

if [ ${v[1]} -ne 3 ]
then
	if [ ${v[74]} -eq 1 ]
	then
                if [ ${v[84]} -eq 0 ]
		then    
		        make -f makefile_PP_lhapdf
		else
		        make -f makefile_onep
		fi    
	else
		if [ ${v[84]} -eq 0 ]
		then
			make -f makefile_PP_standalone
		else
			make -f makefile_onep
		fi
	fi
else
	if [ ${v[74]} -eq 1 ]
	then
	        if [ ${v[84]} -eq 0 ]
		then    
		        make -f makefile_EE_lhapdf
		else
		        make -f makefile_onep
		fi    	
	else
		if [ ${v[84]} -eq 0 ]
		then
			make -f makefile_EE_standalone
		else
			make -f makefile_onep
		fi
	fi
fi

lookfor ${k[5]}

v[5]=`grep -m1 -e "^${k[5]} " $rf | awk '{print $2}'`

if [ -x main_mc_dp.exe ]
then
	mv main_mc_dp.exe ${v[5]}
else
	echo
	echo "Compilation failed"
	exit
fi

n=`grep -c "^${k[2]} " $uif`
if [ $n -eq 0 ]
then
	echo "Error in $uif: ${k[2]} keyword missing"
	exit
else
	if [ $n -gt 1 ]
	then
		echo "Warning: multiple definition of keyword ${k[2]}, using the first occurence"
		warn=1
	fi

	v[2]=`grep -m1 -e "^${k[2]} " $uif`

	wn=`echo ${v[2]} | wc -w`

	mode=0

	for i in `seq 2 "$wn"`
	do
		str=`echo ${v[2]}| awk -v ai="$i" '{print $ai}'`
		fc=`echo $str | awk '{print substr($0,1,1)}'`

		if [ $fc = "#" ]
		then
			i=$((i-1))
			break
		else
			inc[$((i-1))]=$str
		fi

		if [ \( $i -eq 2 \) -a \( $fc = "0" \) ]
		then
			mode=1
			break
		fi
	done

	nip=$((i-1))

	if [ $mode -eq 0 ]
	then
		if [ $nip -lt 2 ]
		then
			echo "Error in ${k[2]} keyword: two initial state particles needed"
			exit
		elif [ $nip -gt 2 ]
		then
			echo "Warning: more than two initial state particles given, using only the first two"
			warn=1
		fi
	fi
fi

n=`grep -c "^${k[3]} " $uif`
if [ $n -eq 0 ]
then
	echo "Error in $uif: ${k[3]} keyword missing"
	exit
else
	if [ $n -gt 1 ]
	then
		echo "Warning: multiple definition of keyword ${k[3]}, using the first occurence"
		warn=1
	fi

	v[3]=`grep -m1 -e "^${k[3]} " $uif`

	wn=`echo ${v[3]} | wc -w`

	for i in `seq 2 "$wn"`
	do
		str=`echo ${v[3]}| awk -v ai="$i" '{print $ai}'`
		fc=`echo $str | awk '{print substr($0,1,1)}'`

		if [ $fc = "#" ]
		then
			i=$((i-1))
			break
		else
			outg[$((i-1))]=$str
		fi
	done

	nop=$((i-1))

	if [ $mode -eq 0 ]
	then
		if [ $nop -lt 2 ]
		then
			echo "Error in ${k[3]} keyword: at least two final state particles needed"
			exit
		fi

		for i in 1 2
		do
			if [ ${outg[$i]} -eq 100 ]
			then
				echo "Error in ${k[3]} keyword: jets are not allowed in single process mode"
				exit
			fi
		done
	fi
fi

x=`seq 1 "$nop"`
v[3]=`for i in $x ; do echo ${outg[i]}; done`

n=`grep -c "^${k[4]} " $uif`
if [ $n -eq 0 ]
then
	echo "Error in $uif: ${k[4]} keyword missing"
	exit
else
	if [ $n -gt 1 ]
	then
		echo "Warning: multiple definition of keyword ${k[4]}, using the first occurence"
		warn=1
	fi

	v[4]=`grep -m1 -e "^${k[4]} " $uif | awk '{print $2}'`

	x=`compute ${v[4]}/2 | grep -o ".*\....."`
	pyt=`echo $pyt $x $x`
fi

for i in `seq 9 11 ; seq 13 20`
do
	lookfor ${k[$i]}

	v[$i]=`grep -m1 -e "^${k[$i]} " $rf | awk '{print $2}'`
done

lookfor ${k[12]}

v[12]=`grep -m1 -e "^${k[12]} " $rf | awk '{print $2}'`

if [ \( ${v[84]} -eq 1 \) -a \( $rf="default.inp" \) ]
then
	v[12]=0
fi

if [ ${v[84]} -eq 1 ]
then
	v[18]="F"

	for i in 85 86
	do
		lookfor ${k[$i]}

		v[$i]=`grep -m1 -e "^${k[$i]} " $rf | awk '{print $2}'`
	done
fi

lookfor ${k[75]}
v[75]=`grep -m1 -e "^${k[75]} " $rf | awk '{print $2}'`

case ${v[15]} in
	1|t|T) v[15]=1;;
	0|f|F) v[15]=0;;
	*) echo "Error in $rf: wrong argument for ${k[15]}"
	   exit;;
esac

for i in 11 17 75
do
	if [ \( ${v[$i]} -lt 0 \) -o \( ${v[$i]} -gt 2 \) ]
	then
		echo "Error in $rf: wrong argument for ${k[$i]}"
		exit
	fi
done

case ${v[17]} in
	0) oqcd="F"
	   wqcd="F";;
	1) oqcd="F"
	   wqcd="T";;
	2) oqcd="T"
	   wqcd="T";;
esac

for i in `seq 12 16`
do
	if [ \( ${v[$i]} -lt 0 \) -o \( ${v[$i]} -gt 1 \) ]
	then
		echo "Error in $rf: wrong argument for ${k[$i]}"
		exit
	fi
done

case ${v[18]} in
	1|t|T) v[18]=T;;
	0|f|F) v[18]=F;;
	*) echo "Error in $rf: wrong argument for ${k[18]}"
		exit;;
esac

if [ $mode -eq 0 ]
then
	lookfor ${k[21]}

	v[21]=`grep -m1 -e "^${k[21]} " $rf | awk '{print $2}'`
else
	for i in 6 22 23
	do
		lookfor ${k[$i]}

		v[$i]=`grep -m1 -e "^${k[$i]} " $rf | awk '{print $2}'`
	done

	if [ \( ${v[6]} -lt -1 \) -o \( ${v[6]} -gt $nop \) ]
	then
		echo "Error in $rf: wrong argument for ${k[6]}"
		exit
	fi

	if [ ${v[6]} -eq -1 ]
	then
		glu="F 0"
	else
		glu="T ${v[6]}"
	fi

	lookfor ${k[73]}

	if [ ${v[1]} -eq 3 ]
	then
		v[73]="0"
	else
		x=`grep -m1 -e "^${k[73]} " $rf | awk '{print $2}'`
		if [ $x -gt 6 ]
		then
			echo "Error in $rf: wrong argument for ${k[73]}"
			exit
		else
			v[73]=$x
		fi
	fi

	x=`grep -m1 -e "^${k[73]} " $rf | awk '{print $3}'`
	if [ $x -gt 6 ]
	then
		echo "Error in $rf: wrong argument for ${k[73]}"
		exit
	else
		v[73]="${v[73]} $x"
	fi
fi

lookfor ${k[24]}
v[24]=`grep -m1 -e "^${k[24]} " $rf | awk '{print $2" "$3" "$4" "$5" "$6" "$7}'`

lookfor ${k[27]}
v[27]=`grep -m1 -e "^${k[27]} " $rf | awk '{print $2" "$3}'`

pyt=`echo $pyt ${v[27]}`

# Flags for coupling power selection
lookfor ${k[93]}
v[93]=`grep -m1 -e "^${k[93]} " $rf | awk '{print $2}'`
lookfor ${k[94]}
v[94]=`grep -m1 -e "^${k[94]} " $rf | awk '{print $2}'`
lookfor ${k[95]}
v[95]=`grep -m1 -e "^${k[95]} " $rf | awk '{print $2}'`

# Generation of input files
if [ $mode -eq 0 ]
then
	if [ ${v[84]} -eq 0 ]
	then
		cat > input_sp <<- EOF
		${v[9]} ${v[10]}
		${v[11]} ${v[12]}
		$((nip+nop))
		EOF
		echo ${inc[1]} ${inc[2]} ${v[3]} >> input_sp
		cat >> input_sp <<- EOF
		0 ${v[14]} ${v[15]} ${v[16]}
		$oqcd $wqcd ${v[13]}
		${v[93]} ${v[94]} ${v[95]} ! Coupling power: flag,maxEWpow,maxQCDpow
		${v[18]} ${v[19]} ${v[20]}
		${v[75]}
		${v[21]}
		${v[24]}
		${v[4]}
		$strfun
		0 0
		$pyt
		EOF
	else
		cat > input_sp <<- EOF
		${v[11]} ${v[12]}
		$((nip+nop))
		EOF
		echo ${inc[1]} ${inc[2]} ${v[3]} >> input_sp
		cat >> input_sp <<- EOF
		0 ${v[14]} ${v[15]} ${v[16]}
		$oqcd $wqcd ${v[13]}
		${v[93]} ${v[94]} ${v[95]} ! Coupling power: flag,maxEWpow,maxQCDpow
		1
		${v[85]}
		${v[86]}
		EOF
	fi
else
	echo $nop > infile
	echo ${v[3]} >> infile
	cat >> infile <<- EOF
	${v[73]}
	F
	$glu
	${v[20]}
	${v[19]}
	EOF

	for i in 0 1
	do
		cat > input$i <<- EOF
		${v[9]} ${v[10]}
		${v[11]} ${v[12]}
		XXXX
		XXXX
		0 ${v[14]} ${v[15]} ${v[16]}
		$oqcd $wqcd ${v[13]}
		${v[93]} ${v[94]} ${v[95]} ! Coupling power: flag,maxEWpow,maxQCDpow
		XXXX
		${v[75]}
		${v[$((22+i))]}
		${v[24]}
		${v[4]}
		$strfun
		0 0
		$pyt
		EOF
	done

	mv input0 Summation_Processes/input
	mv input1 Summation_Processes/
	mv infile Summation_Processes/
fi


if [ $warn -eq 1 ]
then
	echo -n "Press ENTER to ignore the warning messages and continue"
	read dummy
fi

lookfor ${k[25]}

v[25]=`grep -m1 -e "^${k[25]} " $rf | awk '{print $2}'`

RUN=${v[25]}

# clean up
rm -f *.o

#Run
rm -fR $RUN
mkdir $RUN

if [ $mode -eq 1 ]
then
	mkdir $RUN/1

	if [ ${v[18]} = "T" ]
	then
		mkdir $RUN/2
	fi
fi

if [ $mode -eq 0 ]
then
	cd $RUN
	ln -s $LHAPDFSETS linkPDFsets
	ln -s $HELAC/cteq6l1.tbl .
	ln -s $HELAC/seed.input .
	mv $HELAC/${v[5]} .
	mv $HELAC/input_sp .

	if [ ${v[84]} -eq 1 ]
	then
		cp $HELAC/${v[85]} .
	fi

	${v[5]} < input_sp >& output

	cp ../$uif .

	if [ ${v[18]} = "T" ]
	then
		$FC $HELAC/unwei.f -o unwei.exe
		unwei.exe < input_sp >> output
		rm -f fort.* tmp*
	else
		rm -f sample*.init even*.out
	fi

	rm -f data.*

	unlink cteq6l1.tbl
	unlink linkPDFsets
	unlink seed.input
else
	cd Summation_Processes
	ln -s $HELAC/"${v[5]}" $HELAC/main_mc_dp.exe
	cp $HELAC/"${v[5]}" $HELAC/$RUN
	bash clean.sh
	bash script.sh $HELAC $RUN

	rm -f a.out
	cp cross_sections $HELAC/$RUN/1/cross_sections
	cp results.output $HELAC/$RUN/1/results.output
	cp input $HELAC/$RUN/1/
	mv directory* $HELAC/$RUN/1/

	if [ ${v[18]} = "T" ]
	then
		bash clean.sh
		bash script.1.sh $HELAC $RUN

		rm -f a.out temporary* fort.*
		mv sample* $HELAC/$RUN/
		mv results* $HELAC/$RUN/2/
		cp input1 $HELAC/$RUN/2/
		mv directory* $HELAC/$RUN/2/
	fi

	rm -f input*
	rm -f cross*
	rm -f results*
	rm -f temporary*

	bash clean.sh
	mv infile $HELAC/$RUN/
	cd ..
	unlink main_mc_dp.exe
	mv ${v[5]} $HELAC/$RUN/

	cp $HELAC/$uif $HELAC/$RUN/
fi

echo "*********** RESULTS ARE IN SUB-DIRECTORY $RUN"

